@@ -6,6 +6,7 @@ import time
 import logging
 import requests
 from halo import Halo
+from urllib.request import urlopen
 from colorlog import ColoredFormatter
 from datetime import datetime, timedelta
 from requests.exceptions import ConnectionError
@@ -241,14 +242,13 @@ class InnocuousAPI:
         self._get_jwt_token()
         url = self.host + f"/api/experiment/result/{id}"
         r = self.session.get(url, headers=self.headers)
-        self.log.info(json.loads(r.text))
-        self.log.info(r.status_code)
-        self.log.info(json.loads(r.text)['result'])
         if r.status_code == 200 and json.loads(r.text)['result'] == 'ok':
-            self.log.info('correct request')
-            return json.loads(r.text)
+            result_url = json.loads(r.text)['data']['bestconfig']['path']
+            f = urlopen(result_url)
+            result_json = f.read()
+            return json.loads(result_json)
         else:
-            self.log.info('incorrect request, returning None')
+            self.log.info('request error, returning None')
             return None
 
     def kill_experiment(self, id):
